<?php

/*
// Начинаем строить таблицу и выводить данные

$ArrStatTable = [];

if (sizeof($view_personals)) foreach($view_personals as $personal_id=>$rec_person){
    //echo '<tr>';

    // Создать запрос массивом на получение оценок

    $sum_b = getArrOrPerm($intervalSt,$personal_id,$arr_stats); // Сумма балов в прмежутках для конкретного пользователя
    $count_b = getArrOrPerm($intervalSt,$personal_id,$st_c); // Колличесиво баллов (Колличество смен в промежутке) в промежктке для конкретного пользователя
    $sr_b = averageScoreArray($sum_b,$count_b); // Массив среднего балла в промежктке для конкретного пользователя
    $periods_sb = array_values(array_diff($sr_b, array(''))); // Переуды среднего балла, просто удаляем пустые элементы массива

    $srBall = srBall(array_sum($sum_b),array_sum($count_b)); // Ср. по ФИО

    $_work_name = $view_personals[$personal_id]['_work_name'];
    $general_work_name = name_in_post($view_personals_all,$_work_name,$personal_id,$intervalSt,'',$arr_stats,$st_c); // ФИО в такой же должности
    $w_n_b = sr_b_allName($general_work_name); // Ср. по другим ФИО в должности

    $s_1 = graphicalDifference($srBall - $w_n_b,1,-1); // Сигнал к должности
    $s_2 = graphicalDifference($periods_sb[0] - $srBall,1,-1); // К ФИО
    $s_3 = graphicalDifference(min($srBall - $w_n_b,$periods_sb[0] - $srBall),1,-1); // МИН

    $belowAverageScore = belowAverageScore($srBall - $w_n_b,$periods_sb[0] - $srBall); // балл ниже средних
    $dropScore = dropScore($periods_sb); // балл падения

    $overallScore = overallScore($belowAverageScore,$dropScore); // Общий балл

    $srDataTable = array(
        $rec_person['obj_name'].', '.$rec_person['dr'], //('.$personal_id.')'
        $_work_name,
        $rec_person['_otdel_name'],
        $rec_person['_org_name'],
        k_param(srBall($sum_b[0],$count_b[0]),srBall($arr_stats[2][$personal_id],$st_c[2][$personal_id]),srBall($arr_stats[4][$personal_id],$st_c[4][$personal_id]),srBall($arr_stats[8][$personal_id],$st_c[8][$personal_id]),srBall($arr_stats[16][$personal_id],$st_c[16][$personal_id])), // К
        $sr_b[0], // 1 считаем всё после этой даты
        $sr_b[1], // 2
        $sr_b[2], // 4
        $sr_b[3], // 8
        $sr_b[4], // 16 - отладка .' Смен: '.$count_b[4].'/'.$sum_b[4]
        $sr_b[5], // 32
        $sr_b[6], // 64
        $sr_b[7], // 128
        $sr_b[8], // 256 считаем всё до этой даты
        array_sum($count_b), // Смен за весь период
        $srBall, // Ср. по ФИО
        $w_n_b, // Ср. по другим ФИО в должности
        count($general_work_name), // Других ФИО в должности
        $s_1, // К должности
        $s_2, // К ФИО
        $s_3, // МИН
        '-', // Прошлое
        '-', // Задача
        $overallScore, // Общий балл
        $belowAverageScore, // балл ниже средних
        $dropScore, // балл падения
        $periods_sb[0], // 1й период
        $periods_sb[1], // 2й период
        $periods_sb[2], // 3й период
        $periods_sb[3], // 4й период
        $periods_sb[4], // 5й период
        $periods_sb[5], // 6й период
    ); // Наполнение таблицы
    array_push($ArrStatTable,$srDataTable);

}


*/